from .figure import figure
#from . import style
import sys
import os
cwd = os.path.dirname(os.path.realpath(__file__))
sys.path.append(cwd)
